==> bit-bin-0.12.6-dev.8.tgz: package/e2e/commands/init.e2e.js <==
import chai, { expect } from 'chai';
import path from 'path';
import Helper from '../e2e-helper';
import { GIT_HOOKS_NAMES, BIT_GIT_DIR, BIT_HIDDEN_DIR } from '../../src/constants';
// import bitImportGitHook from '../../src/git-hooks/fixtures/bit-import-git-hook';

const assertArrays = require('chai-arrays');

chai.use(assertArrays);
chai.use(require('chai-fs'));

describe('run bit init', function () {
  this.timeout(0);
  const helper = new Helper();
  after(() => {
    helper.destroyEnv();
  });

  // skip since we change the behaviour to work when running bit init twice
  it.skip('Should tell the user there is already a scope when running bit init twice', () => {
    let errorMsg;
    try {
      helper.initLocalScope();
    } catch (err) {
      errorMsg = err.message;
    }
    expect(errorMsg).to.have.string("there's already a scope");
  });
  describe('automatic bit init when .bit.map.json already exists', () => {
    beforeEach(() => {
      helper.reInitLocalScope();
    });
    before(() => {
      helper.createBitMap();
    });
    it('should not tell you there is already a scope when running "bit init"', () => {
      const init = helper.initLocalScope();
      expect(init).to.have.string('successfully initialized an empty bit scope');
    });
    it('should create bitmap"', () => {
      const bitmapPath = path.join(helper.localScopePath, '.bitmap');
      expect(bitmapPath).to.be.a.file('missing bitmap');
    });
    it('bitmap should contain  version"', () => {
      const bitMap = helper.readBitMap();
      expect(bitMap).to.have.property('version');
      expect(bitMap.version).to.equal(helper.getBitVersion());
    });
  });
  describe('default consumer bit.json', () => {
    before(() => {
      helper.reInitLocalScope();
    });
    it('should not contain some default properties', () => {
      const bitJson = helper.readBitJson();
      expect(bitJson).to.not.have.property('dist');
      expect(bitJson).to.not.have.property('extensions');
      expect(bitJson).to.not.have.property('dependenciesDirectory');
      expect(bitJson).to.not.have.property('saveDependenciesAsComponents');
      expect(bitJson).to.not.have.property('useWorkspaces');
      expect(bitJson).to.not.have.property('manageWorkspaces');
    });
  });
  describe('init .bit ', () => {
    describe('when .git exists and bit already initialized with .bit ', () => {
      it('should not create bit inside .git', () => {
        helper.reInitLocalScope();
        helper.initNewGitRepo();
        helper.runCmd('bit init');
        expect(path.join(helper.localScope, '.git', 'bit')).to.not.be.a.path('bit dir is missing');
      });
    });
  });
  describe('git integration', () => {
    describe('when .git exists', () => {
      let gitFolder;
      // let gitHooksFolder;
      before(() => {
        helper.cleanLocalScope();
        helper.initNewGitRepo();
        helper.initLocalScope();
        gitFolder = path.join(helper.localScopePath, '.git');
        // gitHooksFolder = path.join(gitFolder, 'hooks');
      });

      it('should nest the bit folder inside .git by default', () => {
        const gitScopeDir = path.join(gitFolder, BIT_GIT_DIR);
        const scopeDir = path.join(helper.localScopePath, BIT_HIDDEN_DIR);
        expect(gitScopeDir).to.be.a.directory('bit dir is missing');
        // Use not.be.a.path instead of to.not.be.a.directory since for some reason it's not working
        expect(scopeDir).not.be.a.path('bit dir created not in the .git folder');
      });
      it('should not nest the bit folder inside .git if --standalone provided', () => {
        helper.cleanLocalScope();
        helper.initNewGitRepo();
        helper.initLocalScopeWithOptions({ '-standalone': '' });
        const gitScopeDir = path.join(gitFolder, BIT_GIT_DIR);
        const scopeDir = path.join(helper.localScopePath, BIT_HIDDEN_DIR);
        expect(scopeDir).to.be.a.directory('bit dir is missing');
        // Use not.be.a.path instead of to.not.be.a.directory since for some reason it's not working
        expect(gitScopeDir).not.be.a.path('bit dir created incorrectly (in .git folder)');
      });
      // it('should create git hooks', () => {
      //   helper.cleanLocalScope();
      //   helper.initNewGitRepo();
      //   const output = helper.initLocalScope();
      //   const hooksNames = GIT_HOOKS_NAMES.join(', ');
      //   expect(output).to.have.string(`the following git hooks were added: ${hooksNames}`);
      //   GIT_HOOKS_NAMES.forEach((hookName) => {
      //     const hookPath = path.join(gitHooksFolder, hookName);
      //     expect(hookPath)
      //       .to.be.a.file(`hook ${hookName} not found`)
      //       .with.content(bitImportGitHook, `hook ${hookName} has a wrong content`);
      //   });
      // });
      // it('should warn you if git hooks already exists and not override them', () => {
      //   helper.cleanLocalScope();
      //   helper.initNewGitRepo();
      //   const hookContent = 'hook content';
      //   // helper.initLocalScope();
      //   GIT_HOOKS_NAMES.forEach((hookName) => {
      //     helper.writeToGitHook(hookName, hookContent);
      //   });
      //   const output = helper.initLocalScope();
      //   const hooksNames = GIT_HOOKS_NAMES.join(', ');
      //   expect(output).to.have.string(`warning: the following git hooks are already existing: ${hooksNames}`);
      //   GIT_HOOKS_NAMES.forEach((hookName) => {
      //     const hookPath = path.join(gitHooksFolder, hookName);
      //     expect(hookPath)
      //       .to.be.a.file(`hook ${hookName} not found`)
      //       .with.content(hookContent, `hook ${hookName} has a wrong content`);
      //   });
      // });
      // it('should not create git hooks if --standalone provided', () => {
      //   helper.cleanLocalScope();
      //   helper.initNewGitRepo();
      //   const output = helper.initLocalScopeWithOptions({ '-standalone': '' });
      //   expect(output).to.not.have.string('hooks');
      //   GIT_HOOKS_NAMES.forEach((hookName) => {
      //     const hookPath = path.join(gitHooksFolder, hookName);
      //     expect(hookPath).not.be.a.path(`hook ${hookName} created but it should not`);
      //   });
      // });
    });
  });
});

==> bit-bin-0.12.13.tgz: package/e2e/commands/init.e2e.js <==
import chai, { expect } from 'chai';
import path from 'path';
import Helper from '../e2e-helper';
import { GIT_HOOKS_NAMES, BIT_GIT_DIR, BIT_HIDDEN_DIR } from '../../src/constants';
// import bitImportGitHook from '../../src/git-hooks/fixtures/bit-import-git-hook';

const assertArrays = require('chai-arrays');

chai.use(assertArrays);
chai.use(require('chai-fs'));

describe('run bit init', function () {
  this.timeout(0);
  const helper = new Helper();
  after(() => {
    helper.destroyEnv();
  });

  // skip since we change the behaviour to work when running bit init twice
  it.skip('Should tell the user there is already a scope when running bit init twice', () => {
    let errorMsg;
    try {
      helper.initLocalScope();
    } catch (err) {
      errorMsg = err.message;
    }
    expect(errorMsg).to.have.string("there's already a scope");
  });
  describe('automatic bit init when .bit.map.json already exists', () => {
    beforeEach(() => {
      helper.reInitLocalScope();
    });
    before(() => {
      helper.createBitMap();
    });
    it('should not tell you there is already a scope when running "bit init"', () => {
      const init = helper.initLocalScope();
      expect(init).to.have.string('successfully initialized a bit workspace.');
    });
    it('should create bitmap"', () => {
      const bitmapPath = path.join(helper.localScopePath, '.bitmap');
      expect(bitmapPath).to.be.a.file('missing bitmap');
    });
    it('bitmap should contain  version"', () => {
      const bitMap = helper.readBitMap();
      expect(bitMap).to.have.property('version');
      expect(bitMap.version).to.equal(helper.getBitVersion());
    });
  });
  describe('default consumer bit.json', () => {
    before(() => {
      helper.reInitLocalScope();
    });
    it('should not contain some default properties', () => {
      const bitJson = helper.readBitJson();
      expect(bitJson).to.not.have.property('dist');
      expect(bitJson).to.not.have.property('extensions');
      expect(bitJson).to.not.have.property('dependenciesDirectory');
      expect(bitJson).to.not.have.property('saveDependenciesAsComponents');
      expect(bitJson).to.not.have.property('useWorkspaces');
      expect(bitJson).to.not.have.property('manageWorkspaces');
    });
  });
  describe('init .bit ', () => {
    describe('when .git exists and bit already initialized with .bit ', () => {
      it('should not create bit inside .git', () => {
        helper.reInitLocalScope();
        helper.initNewGitRepo();
        helper.runCmd('bit init');
        expect(path.join(helper.localScope, '.git', 'bit')).to.not.be.a.path('bit dir is missing');
      });
    });
  });
  describe('git integration', () => {
    describe('when .git exists', () => {
      let gitFolder;
      // let gitHooksFolder;
      before(() => {
        helper.cleanLocalScope();
        helper.initNewGitRepo();
        helper.initLocalScope();
        gitFolder = path.join(helper.localScopePath, '.git');
        // gitHooksFolder = path.join(gitFolder, 'hooks');
      });

      it('should nest the bit folder inside .git by default', () => {
        const gitScopeDir = path.join(gitFolder, BIT_GIT_DIR);
        const scopeDir = path.join(helper.localScopePath, BIT_HIDDEN_DIR);
        expect(gitScopeDir).to.be.a.directory('bit dir is missing');
        // Use not.be.a.path instead of to.not.be.a.directory since for some reason it's not working
        expect(scopeDir).not.be.a.path('bit dir created not in the .git folder');
      });
      it('should not nest the bit folder inside .git if --standalone provided', () => {
        helper.cleanLocalScope();
        helper.initNewGitRepo();
        helper.initLocalScopeWithOptions({ '-standalone': '' });
        const gitScopeDir = path.join(gitFolder, BIT_GIT_DIR);
        const scopeDir = path.join(helper.localScopePath, BIT_HIDDEN_DIR);
        expect(scopeDir).to.be.a.directory('bit dir is missing');
        // Use not.be.a.path instead of to.not.be.a.directory since for some reason it's not working
        expect(gitScopeDir).not.be.a.path('bit dir created incorrectly (in .git folder)');
      });
      // it('should create git hooks', () => {
      //   helper.cleanLocalScope();
      //   helper.initNewGitRepo();
      //   const output = helper.initLocalScope();
      //   const hooksNames = GIT_HOOKS_NAMES.join(', ');
      //   expect(output).to.have.string(`the following git hooks were added: ${hooksNames}`);
      //   GIT_HOOKS_NAMES.forEach((hookName) => {
      //     const hookPath = path.join(gitHooksFolder, hookName);
      //     expect(hookPath)
      //       .to.be.a.file(`hook ${hookName} not found`)
      //       .with.content(bitImportGitHook, `hook ${hookName} has a wrong content`);
      //   });
      // });
      // it('should warn you if git hooks already exists and not override them', () => {
      //   helper.cleanLocalScope();
      //   helper.initNewGitRepo();
      //   const hookContent = 'hook content';
      //   // helper.initLocalScope();
      //   GIT_HOOKS_NAMES.forEach((hookName) => {
      //     helper.writeToGitHook(hookName, hookContent);
      //   });
      //   const output = helper.initLocalScope();
      //   const hooksNames = GIT_HOOKS_NAMES.join(', ');
      //   expect(output).to.have.string(`warning: the following git hooks are already existing: ${hooksNames}`);
      //   GIT_HOOKS_NAMES.forEach((hookName) => {
      //     const hookPath = path.join(gitHooksFolder, hookName);
      //     expect(hookPath)
      //       .to.be.a.file(`hook ${hookName} not found`)
      //       .with.content(hookContent, `hook ${hookName} has a wrong content`);
      //   });
      // });
      // it('should not create git hooks if --standalone provided', () => {
      //   helper.cleanLocalScope();
      //   helper.initNewGitRepo();
      //   const output = helper.initLocalScopeWithOptions({ '-standalone': '' });
      //   expect(output).to.not.have.string('hooks');
      //   GIT_HOOKS_NAMES.forEach((hookName) => {
      //     const hookPath = path.join(gitHooksFolder, hookName);
      //     expect(hookPath).not.be.a.path(`hook ${hookName} created but it should not`);
      //   });
      // });
    });
  });
});
